Page 42 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 42

Home

    for religion, loyalty to the King, and desire for law and
    order.

    Unfortunately, peaceful reform was not to be the fate
    of France. Plans for violent revolution were already far
    advanced by what was to become known as the
    Orleaniste Conspiracy.

    The principal character in the Orleaniste Conspiracy
    was the Duke of Orleans, a nobleman of great wealth
    who had been recruited into the Iluminati by Mirabeau.
    Lured into supporting the Revolution by the hope of
    attaining the throne in place of his cousin, Louis XVI,
    and driven by his hatred of the Queen, Marie Antoinette,
    the Duke of Orleans became a most willing tool of the

    conspiracy.

    Though hailed as "the idol of Paris," the Duke of
    Orleans was actually loathed and despised by the people.
    This was partly due to his low moral character and partly
    to his disdain for the people. It was no small task for the
    party that supported him to convince the people that the
    man who treated them with insolence had become their

    champion of liberty.
    The election of the Duke of Orleans to Grand Master

    success of the IIuminati's plan (plotted by Mirabeau) to
    infiltrate Freemasonry and to use it as a base of
    operations in promoting violent revolution. Out of these
    Masonic lodges in France came the organization known

    37

    The French Revolution

    of the Masonic Order in France was the crowning